@@ -1,5 +1,5 @@
 import uuid
-from datetime import datetime
+from datetime import datetime, timedelta, timezone
 from unittest.mock import PropertyMock, patch
 
 
@@ -17,6 +17,7 @@ from rq.registry import (
 )
 
 from django_rq import get_queue
+from django_rq.queues import get_scheduler
 from django_rq.workers import get_worker
 
 from .fixtures import access_self, failing_job
@@ -395,3 +396,55 @@ class ViewTest(TestCase):
 
         for job_id in job_ids:
             self.assertIn(job_id, canceled_job_registry)
+
+    def test_scheduler_jobs(self):
+        # Override testing RQ_QUEUES
+        queues = [
+            {
+                "connection_config": {
+                    "DB": 0,
+                    "HOST": "localhost",
+                    "PORT": 6379,
+                },
+                "name": "default",
+            }
+        ]
+        with patch(
+            "django_rq.utils.QUEUES_LIST",
+            new_callable=PropertyMock(return_value=queues),
+        ):
+            scheduler = get_scheduler("default")
+            scheduler_index = get_queue_index("default")
+
+            # Enqueue some jobs
+            cron_job = scheduler.cron("10 9 * * *", func=access_self, id="cron-job")
+            forever_job = scheduler.schedule(
+                scheduled_time=datetime.now() + timedelta(minutes=10),
+                interval=600,
+                func=access_self,
+                id="forever-repeat",
+            )
+            repeat_job = scheduler.schedule(
+                scheduled_time=datetime.now() + timedelta(minutes=30),
+                repeat=30,
+                func=access_self,
+                interval=600,
+                id="thirty-repeat",
+            )
+
+            response = self.client.get(
+                reverse("rq_scheduler_jobs", args=[scheduler_index])
+            )
+            self.assertEqual(response.context["num_jobs"], 3)
+            context_jobs = {job.id: job for job in response.context["jobs"]}
+            self.assertEqual(context_jobs["cron-job"].schedule, "cron: '10 9 * * *'")
+            self.assertEqual(context_jobs["forever-repeat"].schedule, "interval: 600")
+            self.assertEqual(
+                context_jobs["thirty-repeat"].schedule, "interval: 600 repeat: 30"
+            )
+
+            index_response = self.client.get(reverse("rq_home"))
+            self.assertEqual(
+                index_response.context["schedulers"],
+                {"localhost:6379/1": {"count": 3, "index": 0}},
+            )
