@@ -13,6 +13,7 @@ from django.utils.safestring import SafeString
 
 from redis.exceptions import ConnectionError
 from rq import get_current_job, Queue
+import rq
 from rq.exceptions import NoSuchJobError
 from rq.job import Job
 from rq.registry import FinishedJobRegistry, ScheduledJobRegistry
@@ -171,7 +172,7 @@ class QueuesTest(TestCase):
         get_redis_connection(config)
         sentinel_init_sentinel_kwargs = sentinel_class_mock.call_args[1]
         self.assertDictEqual(
-            sentinel_init_sentinel_kwargs, 
+            sentinel_init_sentinel_kwargs,
             {'db': 0, 'username': 'redis-user', 'password': 'redis-pass', 'socket_timeout': 0.2, 'ssl': False, 'sentinel_kwargs': {'username': 'sentinel-user', 'password': 'sentinel-pass', 'socket_timeout': 0.3}}
         )
 
@@ -285,6 +286,23 @@ class QueuesTest(TestCase):
             self.assertTrue(job['job'].is_finished)
             self.assertIn(job['job'].id, job['finished_job_registry'].get_job_ids())
 
+        # Test with rqworker-pool command
+        jobs = []
+        for queue_name in queue_names:
+            queue = get_queue(queue_name)
+            jobs.append(
+                {
+                    'job': queue.enqueue(divide, 42, 1),
+                    'finished_job_registry': FinishedJobRegistry(queue.name, queue.connection),
+                }
+            )
+
+        call_command('rqworker-pool', *queue_names, burst=True)
+
+        for job in jobs:
+            self.assertTrue(job['job'].is_finished)
+            self.assertIn(job['job'].id, job['finished_job_registry'].get_job_ids())
+
     def test_configure_sentry(self):
         rqworker.configure_sentry('https://1@sentry.io/1')
         self.mock_sdk.init.assert_called_once_with(
@@ -457,6 +475,14 @@ class QueuesTest(TestCase):
         queue = get_queue('test1')
         self.assertEqual(queue._default_timeout, 400)
 
+    def test_get_queue_serializer(self):
+        """
+        Test that the correct serializer is set on the queue.
+        """
+        queue = get_queue('test_serializer')
+        self.assertEqual(queue.name, 'test_serializer')
+        self.assertEqual(queue.serializer, rq.serializers.JSONSerializer)
+
 
 @override_settings(RQ={'AUTOCOMMIT': True})
 class DecoratorTest(TestCase):
@@ -834,14 +860,14 @@ class SchedulerPIDTest(TestCase):
                 'PORT': 6379,
             },
             'name': test_queue,
-        }]        
+        }]
         with patch('django_rq.utils.QUEUES_LIST',
             new_callable=PropertyMock(return_value=queues)):
             scheduler = get_scheduler(test_queue)
             scheduler.register_birth()
             self.assertIs(get_scheduler_pid(get_queue(scheduler.queue_name)), False)
             scheduler.register_death()
-    
+
     @skipIf(RQ_SCHEDULER_INSTALLED is False, 'RQ Scheduler not installed')
     def test_scheduler_scheduler_pid_inactive(self):
         test_queue = 'scheduler_scheduler_inactive_test'
@@ -852,7 +878,7 @@ class SchedulerPIDTest(TestCase):
                 'PORT': 6379,
             },
             'name': test_queue,
-        }]        
+        }]
         with patch('django_rq.utils.QUEUES_LIST',
             new_callable=PropertyMock(return_value=queues)):
             connection = get_connection(test_queue)
@@ -896,7 +922,7 @@ class SchedulerPIDTest(TestCase):
                 'PORT': 6379,
             },
             'name': test_queue,
-        }]        
+        }]
         with patch('django_rq.utils.QUEUES_LIST',
             new_callable=PropertyMock(return_value=queues)):
             worker = get_worker(test_queue, name=uuid4().hex)
