@@ -9,6 +9,5 @@ urlpatterns = [
     path('admin/', admin.site.urls),
     path('success/', views.success, name='success'),
     path('error/', views.error, name='error'),
-    path('django-rq/', (urlpatterns, '', 'django_rq'))
+    path('django-rq/', (urlpatterns, '', 'django_rq')),
 ]
-
