@@ -1,3 +1,6 @@
+from django.core.exceptions import ImproperlyConfigured
+from django.db import connections
+from rq.command import send_stop_job_command
 from rq.job import Job
 from rq.registry import (
     DeferredJobRegistry,
@@ -7,20 +10,18 @@ from rq.registry import (
     StartedJobRegistry,
     clean_registries,
 )
-from rq.command import send_stop_job_command
 from rq.worker import Worker
 from rq.worker_registration import clean_worker_registry
 
-
 from .queues import get_connection, get_queue_by_index, get_scheduler
 from .settings import QUEUES_LIST
 from .templatetags.django_rq import to_localtime
-from django.core.exceptions import ImproperlyConfigured
+
 
 def get_scheduler_pid(queue):
     '''Checks whether there's a scheduler-lock on a particular queue, and returns the PID.
         It Only works with RQ's Built-in RQScheduler.
-        When RQ-Scheduler is available returns False 
+        When RQ-Scheduler is available returns False
         If not, it checks the RQ's RQScheduler for a scheduler lock in the desired queue
         Note: result might have some delay (1-15 minutes) but it helps visualizing whether the setup is working correcly
     '''
@@ -30,8 +31,9 @@ def get_scheduler_pid(queue):
         return False  # Not possible to give useful information without creating a performance issue (redis.keys())
     except ImproperlyConfigured:
         from rq.scheduler import RQScheduler
+
         # When a scheduler acquires a lock it adds an expiring key: (e.g: rq:scheduler-lock:<queue.name>)
-        #TODO: (RQ>= 1.13) return queue.scheduler_pid 
+        #TODO: (RQ>= 1.13) return queue.scheduler_pid
         pid = queue.connection.get(RQScheduler.get_locking_key(queue.name))
         return int(pid.decode()) if pid is not None else None
     except Exception as e:
@@ -89,15 +91,37 @@ def get_statistics(run_maintenance_tasks=False):
         queue_data['scheduled_jobs'] = len(scheduled_job_registry)
 
         queues.append(queue_data)
+
     return {'queues': queues}
 
 
+def get_scheduler_statistics():
+    schedulers = {}
+    for index, config in enumerate(QUEUES_LIST):
+        # there is only one scheduler per redis connection, so we use the connection as key
+        # to handle the possibility of a configuration with multiple redis connections and scheduled
+        # jobs in more than one of them
+        queue = get_queue_by_index(index)
+        connection_kwargs = queue.connection.connection_pool.connection_kwargs
+        conn_key = f"{connection_kwargs['host']}:{connection_kwargs['port']}/{connection_kwargs.get('db', 0)}"
+        if conn_key not in schedulers:
+            try:
+                scheduler = get_scheduler(config['name'])
+                schedulers[conn_key] ={
+                    'count': scheduler.count(),
+                    'index': index,
+                }
+            except ImproperlyConfigured:
+                pass
+    return {'schedulers': schedulers}
+
+
 def get_jobs(queue, job_ids, registry=None):
     """Fetch jobs in bulk from Redis.
     1. If job data is not present in Redis, discard the result
     2. If `registry` argument is supplied, delete empty jobs from registry
     """
-    jobs = Job.fetch_many(job_ids, connection=queue.connection)
+    jobs = Job.fetch_many(job_ids, connection=queue.connection, serializer=queue.serializer)
     valid_jobs = []
     for i, job in enumerate(jobs):
         if job is None:
@@ -108,6 +132,7 @@ def get_jobs(queue, job_ids, registry=None):
 
     return valid_jobs
 
+
 def stop_jobs(queue, job_ids):
     job_ids = job_ids if isinstance(job_ids, (list, tuple)) else [job_ids]
     stopped_job_ids = []
@@ -119,4 +144,37 @@ def stop_jobs(queue, job_ids):
             failed_to_stop_job_ids.append(job_id)
             continue
         stopped_job_ids.append(job_id)
-    return stopped_job_ids, failed_to_stop_job_ids
\ No newline at end of file
+    return stopped_job_ids, failed_to_stop_job_ids
+
+
+def reset_db_connections():
+    for c in connections.all():
+        c.close()
+
+
+def configure_sentry(sentry_dsn, **options):
+    """
+    Configure the Sentry client.
+
+    The **options kwargs are passed straight from the command
+    invocation - options relevant to Sentry configuration are
+    extracted.
+
+    In addition to the 'debug' and 'ca_certs' options, which can
+    be passed in as command options, we add the RqIntegration and
+    DjangoIntegration to the config.
+
+    Raises ImportError if the sentry_sdk is not available.
+
+    """
+    import sentry_sdk
+    sentry_options = {
+        'debug': options.get('sentry_debug', False),
+        'ca_certs': options.get('sentry_ca_certs', None),
+        'integrations': [
+            sentry_sdk.integrations.redis.RedisIntegration(),
+            sentry_sdk.integrations.rq.RqIntegration(),
+            sentry_sdk.integrations.django.DjangoIntegration()
+        ]
+    }
+    sentry_sdk.init(sentry_dsn, **sentry_options)
