@@ -9,7 +9,6 @@ from django.shortcuts import redirect, render
 from django.urls import reverse
 from django.views.decorators.cache import never_cache
 from django.views.decorators.http import require_POST
-
 from redis.exceptions import ResponseError
 from rq import requeue_job
 from rq.exceptions import NoSuchJobError
@@ -23,17 +22,20 @@ from rq.registry import (
 )
 from rq.worker import Worker
 from rq.worker_registration import clean_worker_registry
-from rq.command import send_stop_job_command
 
-from .queues import get_queue_by_index
-from .settings import API_TOKEN
-from .utils import get_statistics, get_jobs, stop_jobs
+from .queues import get_queue_by_index, get_scheduler_by_index
+from .settings import API_TOKEN, QUEUES_MAP
+from .utils import get_jobs, get_scheduler_statistics, get_statistics, stop_jobs
 
 
 @never_cache
 @staff_member_required
 def stats(request):
-    context_data = {**admin.site.each_context(request), **get_statistics(run_maintenance_tasks=True)}
+    context_data = {
+        **admin.site.each_context(request),
+        **get_statistics(run_maintenance_tasks=True),
+        **get_scheduler_statistics(),
+    }
     return render(request, 'django_rq/stats.html', context_data)
 
 
@@ -287,7 +289,7 @@ def deferred_jobs(request, queue_index):
 
         for job_id in job_ids:
             try:
-                jobs.append(Job.fetch(job_id, connection=queue.connection))
+                jobs.append(Job.fetch(job_id, connection=queue.connection, serializer=queue.serializer))
             except NoSuchJobError:
                 pass
 
@@ -314,7 +316,7 @@ def job_detail(request, queue_index, job_id):
     queue = get_queue_by_index(queue_index)
 
     try:
-        job = Job.fetch(job_id, connection=queue.connection)
+        job = Job.fetch(job_id, connection=queue.connection, serializer=queue.serializer)
     except NoSuchJobError:
         raise Http404("Couldn't find job with this ID: %s" % job_id)
 
@@ -351,7 +353,7 @@ def job_detail(request, queue_index, job_id):
 def delete_job(request, queue_index, job_id):
     queue_index = int(queue_index)
     queue = get_queue_by_index(queue_index)
-    job = Job.fetch(job_id, connection=queue.connection)
+    job = Job.fetch(job_id, connection=queue.connection, serializer=queue.serializer)
 
     if request.method == 'POST':
         # Remove job id from queue and delete the actual job
@@ -374,10 +376,10 @@ def delete_job(request, queue_index, job_id):
 def requeue_job_view(request, queue_index, job_id):
     queue_index = int(queue_index)
     queue = get_queue_by_index(queue_index)
-    job = Job.fetch(job_id, connection=queue.connection)
+    job = Job.fetch(job_id, connection=queue.connection, serializer=queue.serializer)
 
     if request.method == 'POST':
-        requeue_job(job_id, connection=queue.connection)
+        requeue_job(job_id, connection=queue.connection, serializer=queue.serializer)
         messages.info(request, 'You have successfully requeued %s' % job.id)
         return redirect('rq_job_detail', queue_index, job_id)
 
@@ -431,7 +433,7 @@ def requeue_all(request, queue_index):
         # Confirmation received
         for job_id in job_ids:
             try:
-                requeue_job(job_id, connection=queue.connection)
+                requeue_job(job_id, connection=queue.connection, serializer=queue.serializer)
                 count += 1
             except NoSuchJobError:
                 pass
@@ -449,6 +451,35 @@ def requeue_all(request, queue_index):
     return render(request, 'django_rq/requeue_all.html', context_data)
 
 
+@never_cache
+@staff_member_required
+def delete_failed_jobs(request, queue_index):
+    queue_index = int(queue_index)
+    queue = get_queue_by_index(queue_index)
+    registry = FailedJobRegistry(queue=queue)
+
+    if request.method == 'POST':
+        job_ids = registry.get_job_ids()
+        jobs = Job.fetch_many(job_ids, connection=queue.connection)
+        count = 0
+        for job in jobs:
+            if job:
+                job.delete()
+                count += 1
+
+        messages.info(request, 'You have successfully deleted %d jobs!' % count)
+        return redirect('rq_home')
+
+    context_data = {
+        **admin.site.each_context(request),
+        'queue_index': queue_index,
+        'queue': queue,
+        'total_jobs': len(registry),
+    }
+
+    return render(request, 'django_rq/clear_failed_queue.html', context_data)
+
+
 @never_cache
 @staff_member_required
 def confirm_action(request, queue_index):
@@ -486,14 +517,14 @@ def actions(request, queue_index):
 
             if request.POST['action'] == 'delete':
                 for job_id in job_ids:
-                    job = Job.fetch(job_id, connection=queue.connection)
+                    job = Job.fetch(job_id, connection=queue.connection, serializer=queue.serializer)
                     # Remove job id from queue and delete the actual job
                     queue.connection.lrem(queue.key, 0, job.id)
                     job.delete()
                 messages.info(request, 'You have successfully deleted %s jobs!' % len(job_ids))
             elif request.POST['action'] == 'requeue':
                 for job_id in job_ids:
-                    requeue_job(job_id, connection=queue.connection)
+                    requeue_job(job_id, connection=queue.connection, serializer=queue.serializer)
                 messages.info(request, 'You have successfully requeued %d  jobs!' % len(job_ids))
             elif request.POST['action'] == 'stop':
                 stopped, failed_to_stop = stop_jobs(queue, job_ids)
@@ -511,7 +542,7 @@ def enqueue_job(request, queue_index, job_id):
     """Enqueue deferred jobs"""
     queue_index = int(queue_index)
     queue = get_queue_by_index(queue_index)
-    job = Job.fetch(job_id, connection=queue.connection)
+    job = Job.fetch(job_id, connection=queue.connection, serializer=queue.serializer)
 
     if request.method == 'POST':
         try:
@@ -557,4 +588,45 @@ def stop_job(request, queue_index, job_id):
         return redirect('rq_job_detail', queue_index, job_id)
     else:
         messages.error(request, 'Failed to stop %s' % job_id)
-        return redirect('rq_job_detail', queue_index, job_id)
\ No newline at end of file
+        return redirect('rq_job_detail', queue_index, job_id)
+
+
+@never_cache
+@staff_member_required
+def scheduler_jobs(request, scheduler_index):
+    scheduler = get_scheduler_by_index(scheduler_index)
+
+    items_per_page = 100
+    num_jobs = scheduler.count()
+    page = int(request.GET.get('page', 1))
+    jobs = []
+
+    if num_jobs > 0:
+        last_page = int(ceil(num_jobs / items_per_page))
+        page_range = range(1, last_page + 1)
+        offset = items_per_page * (page - 1)
+        jobs_times = scheduler.get_jobs(with_times=True, offset=offset, length=items_per_page)
+        for job, time in jobs_times:
+            job.next_run = time
+            job.queue_index = QUEUES_MAP.get(job.origin, 0)
+            if 'cron_string' in job.meta:
+                job.schedule = f"cron: '{job.meta['cron_string']}'"
+            elif 'interval' in job.meta:
+                job.schedule = f"interval: {job.meta['interval']}"
+                if 'repeat' in job.meta:
+                    job.schedule += f" repeat: {job.meta['repeat']}"
+            else:
+                job.schedule = 'unknown'
+            jobs.append(job)
+    else:
+        page_range = []
+
+    context_data = {
+        **admin.site.each_context(request),
+        'scheduler': scheduler,
+        'jobs': jobs,
+        'num_jobs': num_jobs,
+        'page': page,
+        'page_range': page_range,
+    }
+    return render(request, 'django_rq/scheduler.html', context_data)
